/*
 * Arduino code to use a Wii Nunchuck's joystick to control a stepper motor, driven by an Adafruit Motor
 * Shield V2.
 * 
 * Made by TechBuild: https://www.youtube.com/channel/UCNy7DyfhSD9jsQEgNwETp9g?sub_confirmation=1
 * 
 * The horizontal(or X) axis of the joystick controls the motor in the following way:
 * >Moving the joystick to the right makes the motor go clockwise(depending on wiring)
 * >Moving the joystick to the left makes the motor go anti-clockwise(depending on wiring)
 * 
 * The speed of the motor depends on the distance of the joystick from the center.
 * The motor will go faster, the farther the joystick is away from the center.
 * 
 * Feel free to modify the code to suit your requirements.
 * All the best!
 */
#include <Wire.h>
#include <Nunchuk.h>
#include <Adafruit_MotorShield.h>
#include <AccelStepper.h>

Adafruit_MotorShield AFMS = Adafruit_MotorShield();

Adafruit_StepperMotor *stepper1 = AFMS.getStepper(960, 2);

int cp, pos = 0, sp = 0;
int x, y, x1, y1, cc;


void fwdstep()
{
  stepper1->onestep(FORWARD, SINGLE);
}

void bkwdstep()
{
  stepper1->onestep(BACKWARD, SINGLE);
}

AccelStepper stepper(fwdstep, bkwdstep);

void setup() {
  // put your setup code here, to run once:

  Wire.begin();
  AFMS.begin();
  Serial.begin(9600);

  // Change TWI speed for nuchuk, which uses Fast-TWI (400kHz)
  Wire.setClock(400000);

  // nunchuk_init_power(); // A1 and A2 is power supply
  nunchuk_init();

  stepper.setMaxSpeed(250);
  stepper.setAcceleration(200);

  pinMode(13, OUTPUT);

}

void loop() {
  // put your main code here, to run repeatedly:

  nunchuk_read();

  x1 = nunchuk_joystickX();

  y1 = nunchuk_joystickY();

  cc = nunchuk_buttonC();

  if (x1 <= 5) x = map(x1, -127, 5, -128, 0);

  if (x1 > 5) x = map(x1, 6, 128, 0, 128);

  if (y1 <= 2) y = map(y1, -128, 2, -128, 0);

  if (y1 > 2) y = map(y1, 3, 127, 0, 128);

  cp = stepper.currentPosition();

  if (x > 0)
  {
    sp = map(x, 0, 128, 20, 300);

    stepper.setSpeed(sp);

    stepper.move(10);

  }

  if (x < 0)
  {
    sp = map(x, -128, 0, 300, 20);

    stepper.setSpeed(-sp);

    stepper.move(-10);

  }

  if ( x == 0)
  {
    stepper.stop();

    sp = 0;

    stepper.setSpeed(sp);
  }

  if(cc == 1)
  {
    stepper.moveTo(0);

    stepper.runToPosition();
  }

  stepper.run();




}
